@@ -117,6 +117,23 @@ struct sockaddr_storage
 };
 #endif
 
+#ifndef	SOCK_DCCP
+#define	SOCK_DCCP		6
+#endif
+
+#ifndef	IPPROTO_DCCP
+#define	IPPROTO_DCCP	23
+#endif
+
+#ifndef	SOL_DCCP
+#define	SOL_DCCP		269
+#endif
+
+#define DCCP_SOCKOPT_AVAILABLE_CCIDS    12
+#define DCCP_SOCKOPT_CCID               13
+#define DCCP_SOCKOPT_TX_CCID            14
+#define DCCP_SOCKOPT_RX_CCID            15
+
 NAMESPACE_UCOMMON
 
 /**
@@ -721,6 +738,22 @@ public:
 	 */
 	static int gettype(socket_t socket);
 
+	/**
+	 * Set segment size and get MTU.
+	 * @param socket to modify.
+	 * @param segment size or zero to not set.
+	 * @return mtu size of socket.
+	 */
+	static unsigned segsize(socket_t socket, unsigned size = 0);
+
+	/**
+	 * Set congestion control id.
+	 * @param socket to modify.
+	 * @param ccid value to set.
+	 * @return true if success, false if not dccp or not supported ccid used.
+	 */
+	static bool setccid(socket_t socket, uint8_t ccid);
+
 	/**
 	 * Get the type of a socket.
 	 * @return socket type.
@@ -728,6 +761,22 @@ public:
 	inline int gettype(void)
 		{return gettype(so);};
 
+	/**
+	 * Set segment size and get mtu of a socket.
+	 * @param segment size to set or 0 to leave unchanged.
+	 * @return mtu size.
+	 */
+	inline unsigned segsize(unsigned size)
+		{return segsize(so, size);};
+
+	/**
+	 * Set ccid of dccp socket.
+	 * @param ccid to set.
+	 * @return true if success, false if not dccp or not supported ccid used.
+	 */
+	inline bool setccid(uint8_t ccid)
+		{return setccid(so, ccid);};
+
 	/**
 	 * Set the type of service field of outgoing packets.  Some useful
 	 * values include IPTOS_LOWDELAY to minimize delay for interactive 
@@ -756,8 +805,8 @@ public:
 
 	/**
 	 * Connect our socket to a remote host from an address list.
-	 * For TCP sockets, the entire list may be tried.  For UDP, connect
-	 * is only a state and the first valid entry in the list is used.
+	 * For TCP (and DCCP) sockets, the entire list may be tried.  For UDP, 
+	 * connect is only a state and the first valid entry in the list is used.
 	 * @param list of addresses to connect to.
 	 * @return 0 on success, -1 on error.
 	 */
@@ -924,8 +973,8 @@ public:
 
 	/**
 	 * Connect socket descriptor to a remote host from an address list.
-	 * For TCP sockets, the entire list may be tried.  For UDP, connect
-	 * is only a state and the first valid entry in the list is used.
+	 * For TCP (and DCCP) sockets, the entire list may be tried.  For UDP, 
+	 * connect is only a state and the first valid entry in the list is used.
 	 * @param socket descriptor.
 	 * @param list of addresses to connect to.
 	 * @return 0 on success, -1 on error.
@@ -1448,7 +1497,7 @@ public:
 
 /**
  * A bound socket used to listen for inbound socket connections.  This class 
- * is commonly used for TCP listener sockets.
+ * is commonly used for TCP and DCCP listener sockets.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
 class __EXPORT ListenSocket : protected Socket
